@@ -17,10 +17,7 @@ def _name_to_words(name):
     name = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
     words = re.split('[_\s]+', name)
 
-    def capitalize(s):
-        return s[0].upper() + s[1:]
-
-    return ' '.join([capitalize(w) for w in words])
+    return ' '.join([w.title() for w in words])
 
 
 def create_backend_manager(model):
@@ -93,7 +90,7 @@ class Manager(object):
 
     @property
     def column_names(self):
-        return []
+        return dir(self.Model)
 
     @reify
     def default_actions(self):
@@ -204,15 +201,14 @@ class Manager(object):
 
     @property
     def __default_list__columns_to_display__(self):
-        columns = dict(zip(dir(self.Model), dir(self.Model)))
-        columns[self.id_attr] = '#'
-        return columns
+        return OrderedDict(zip(
+            self.column_names,
+            [_name_to_words(n) for n in self.column_names]
+        ))
 
     @property
     def __default_detail__columns_to_display__(self):
-        columns = dict(zip(dir(self.Model), dir(self.Model)))
-        columns[self.id_attr] = '#'
-        return columns
+        return self.__default_list__columns_to_display__
 
     @property
     def __default_detail__relations_to_display__(self):
@@ -256,7 +252,7 @@ class Manager(object):
     def update(self, obj, data):
         raise NotImplementedError()
 
-    def fetch_objects(self, filters, page=1):
+    def fetch_objects(self, filters, fulltext=True, page=1):
         raise NotImplementedError()
 
     def count_objects(self, filters):
@@ -264,5 +260,5 @@ class Manager(object):
 
     def find_object(self, id_value):
         id_filters = self.get_id_filters(id_value)
-        objs = self.fetch_objects(id_filters)
+        objs = list(self.fetch_objects(id_filters, fulltext=False))
         return objs[0] if objs else None
