@@ -4,13 +4,20 @@ __author__ = 'tarzan'
 import inspect
 from collections import OrderedDict
 from pyramid.decorator import reify
-import importlib
 from . import Manager, _name_to_words, AttrDisplayConf as _BaseAttrDisplayConf
-from cqlengine.models import (
-    Model as CQLEngineModel,
-)
-from cqlengine.exceptions import  ValidationError
-from cqlengine.query import ModelQuerySet
+try:
+    from cqlengine.models import (
+        Model as CQLEngineModel,
+    )
+    from cqlengine.exceptions import  ValidationError
+    from cqlengine.query import ModelQuerySet
+except ImportError:
+    class CQLEngineModel(object):
+        pass
+    class ValidationError(object):
+        pass
+    class ModelQuerySet(object):
+        pass
 
 
 def factory(config):
@@ -54,18 +61,6 @@ class CQLEngineManager(Manager):
     def column(self, col_name):
         return getattr(self.Model, col_name)
 
-    @property
-    def __default_list__columns_to_display__(self):
-        columns = OrderedDict(zip(self.column_names, [_name_to_words(n) for n in self.column_names]))
-        columns[self.id_attr] = '#'
-        return columns
-
-    @property
-    def __default_detail__columns_to_display__(self):
-        columns = OrderedDict(zip(self.column_names, [_name_to_words(n) for n in self.column_names]))
-        columns[self.id_attr] = '#'
-        return columns
-
     @property
     def __default_detail__relations_to_display__(self):
         return []
@@ -81,7 +76,7 @@ class CQLEngineManager(Manager):
     def delete(self, obj):
         obj.delete()
 
-    def fetch_objects(self, filters, page=1):
+    def fetch_objects(self, filters, fulltext=True, page=1):
         criteria = []
         for name, value in filters.items():
             if name in self.column_names:
