@@ -12,13 +12,20 @@ def factory(config):
 
 try:
     from sqlalchemy import func, Table
+    from sqlalchemy.orm.attributes import InstrumentedAttribute
+    from sqlalchemy.orm.properties import ColumnProperty
+    from sqlalchemy import inspect
+    from sqlalchemy.exc import NoInspectionAvailable
     _sqlalchemy_is_available = True
 except ImportError:  # sqlalchemy is not available
     _sqlalchemy_is_available = False
     func = object()
-
     class Table(object):
         pass
+    class InstrumentedAttribute(object):
+        pass
+    class ColumnProperty(object):
+        pass
 
 
 if _sqlalchemy_is_available:
@@ -43,10 +50,8 @@ if _sqlalchemy_is_available:
             # verify model is an ORM class of SQLAlchemy or not
             # if not, just return None
             try:
-                table = model.__table__
-            except AttributeError:
-                return None
-            if not isinstance(table, Table):
+                mapper = inspect(model)
+            except NoInspectionAvailable:
                 return None
             return SQLAlchemyManager(model)
 
@@ -56,32 +61,21 @@ if _sqlalchemy_is_available:
 
         @reify
         def column_names(self):
-            return [c.name for c in self.Model.__table__.columns]
+            def is_column(col):
+                return \
+                    isinstance(col, InstrumentedAttribute) \
+                    and isinstance(col.property, ColumnProperty)
+            col_names_in_order = inspect(self.Model).local_table.columns.keys()
+            c2a = {c.name: a for a, c in self.Model.__dict__.items() if is_column(c)}
+            col_names = [c2a[col] for col in col_names_in_order]
+            return list(self.id_attr) + [c for c in col_names if c not in self.id_attr]
 
         def column(self, col_name):
             return getattr(self.Model, col_name)
 
         @property
         def _foreignkey_names(self):
-            return [rel.key for rel in self.Model.__mapper__.relationships]
-
-        @property
-        def __default_list__columns_to_display__(self):
-            columns = OrderedDict(zip(
-                self.column_names,
-                [_name_to_words(n) for n in self.column_names]
-            ))
-            columns[self.id_attr] = '#'
-            return columns
-
-        @property
-        def __default_detail__columns_to_display__(self):
-            columns = OrderedDict(zip(
-                self.column_names,
-                [_name_to_words(n) for n in self.column_names]
-            ))
-            columns[self.id_attr] = '#'
-            return columns
+            return [rel.key for rel in inspect(self.Model).relationships]
 
         @property
         def __default_detail__relations_to_display__(self):
@@ -109,25 +103,27 @@ if _sqlalchemy_is_available:
             DBSession.delete(obj)
             DBSession.flush()
 
-        def fetch_objects(self, filters, page=1):
+        def fetch_objects(self, filters, fulltext=True, page=1):
             query = DBSession.query(self.Model)
             for name, value in filters.items():
                 if name in self.column_names:
-                    query = query.filter(self.column(name).like("%%%s%%" % value))
+                    if fulltext:
+                        query = query.filter(self.column(name)
+                                             .like("%%%s%%" % value))
+                    else:
+                        query = query.filter(self.column(name) == value)
             limit = self.list__items_per_page
             offset = (page-1)*limit
-            id_col = self.column(self.id_attr)
-            query = query.order_by(id_col.desc())
+            id_cols = [self.column(id_attr) for id_attr in self.id_attr]
+            for id_col in id_cols:
+                query = query.order_by(id_col.desc())
             query = query.offset(offset).limit(limit)
             return query
 
         def count_objects(self, filters):
-            id_col = self.column(self.id_attr)
-            query = DBSession.query(func.count(id_col))
+            query = DBSession.query(func.count('*'))
             for name, value in filters.items():
                 if name in self.column_names:
                     query = query.filter(self.column(name).like("%%%s%%" % value))
-            return query.scalar()
 
-        # def find_object(self, id_value):
-        #     return DBSession.query(self.Model).filter(self.column(self.id_attr) == id_value).first()
\ No newline at end of file
+            return query.scalar()
\ No newline at end of file
